@@ -335,19 +335,22 @@ IODVDServices::AsyncReadWriteComplete ( void * 			clientData,
 	returnData 	= bsClientData->completionData;
 	owner 		= bsClientData->owner;
 	
-	if ((( status != kIOReturnNotAttached ) && ( status != kIOReturnOffline ) &&
-		( status != kIOReturnSuccess )) && ( bsClientData->retriesLeft > 0 ))
+	if ( ( ( status != kIOReturnNotAttached ) && ( status != kIOReturnOffline ) &&
+		 ( status != kIOReturnUnsupportedMode ) && ( status != kIOReturnSuccess ) ) &&
+		 ( bsClientData->retriesLeft > 0 ) )
 	{
+		
 		IOReturn 	requestStatus;
-
-		STATUS_LOG(("IODVDServices: AsyncReadWriteComplete; retry command\n"));
+		
+		STATUS_LOG ( ( "IODVDServices: AsyncReadWriteComplete; retry command\n" ) );
 		// An error occurred, but it is one on which the command should be retried.  Decrement
 		// the retry counter and try again.
 		bsClientData->retriesLeft--;
 		if ( bsClientData->clientReadCDCall == true )
 		{
+		
 #if (_DVD_USE_DATA_CACHING_)
-			requestStatus = owner->fProvider->AsyncReadCD( 
+			requestStatus = owner->fProvider->AsyncReadCD (
 											bsClientData->transferSegDesc,
 											bsClientData->transferStart,
 											bsClientData->transferCount,
@@ -355,7 +358,7 @@ IODVDServices::AsyncReadWriteComplete ( void * 			clientData,
 											bsClientData->clientSectorType,
 											clientData );
 #else
-			requestStatus = owner->fProvider->AsyncReadCD( 
+			requestStatus = owner->fProvider->AsyncReadCD (
 											bsClientData->clientBuffer, 
 											bsClientData->clientStartingBlock, 
 											bsClientData->clientRequestedBlockCount, 
@@ -363,28 +366,35 @@ IODVDServices::AsyncReadWriteComplete ( void * 			clientData,
 											bsClientData->clientSectorType,
 											clientData );
 #endif
+		
 		}
+		
 		else
 		{
-			requestStatus = owner->fProvider->AsyncReadWrite( 
+			
+			requestStatus = owner->fProvider->AsyncReadWrite (
 											bsClientData->clientBuffer, 
 											bsClientData->clientStartingBlock, 
 											bsClientData->clientRequestedBlockCount, 
 											clientData );
+			
 		}
-
+		
 		if ( requestStatus != kIOReturnSuccess )
 		{
 			commandComplete = true;
 		}
+		
 		else
 		{
 			commandComplete = false;
 		}
+	
 	}
 
 	if ( commandComplete == true )
 	{		
+
 #if (_DVD_USE_DATA_CACHING_)
 		// Check to see if there was a temporary transfer buffer
 		if ( bsClientData->transferSegBuffer != NULL )
@@ -406,20 +416,20 @@ IODVDServices::AsyncReadWriteComplete ( void * 			clientData,
 			}
 			
 			( bsClientData->transferSegDesc )->release ( );
-
+			
 			// Since the buffer is the entire size of the client's requested transfer ( not just the amount transferred), 
 			// make sure to release the whole allocation.
 			IOFree ( bsClientData->transferSegBuffer, ( bsClientData->clientRequestedBlockCount * _CACHE_BLOCK_SIZE_ ) );
 			
 		}
-
+		
 		// Make sure that the transfer completed successfully.
 		if ( status == kIOReturnSuccess )
 		{
-		
+			
 			// Check to see if this was a Read CD call for a CDDA sector and if so,
 			// store cache data.
-			if (( bsClientData->clientReadCDCall == true ) && ( bsClientData->clientSectorType == kCDSectorTypeCDDA ))
+			if ( ( bsClientData->clientReadCDCall == true ) && ( bsClientData->clientSectorType == kCDSectorTypeCDDA ) )
 			{
 				
 				// Save the last blocks into the data cache
@@ -431,12 +441,12 @@ IODVDServices::AsyncReadWriteComplete ( void * 			clientData,
 				{
 					
 					UInt32	offset;
-						
+					
 					// Calculate the beginning of data to copy into cache.
 					offset = ( ( bsClientData->clientRequestedBlockCount - _CACHE_BLOCK_COUNT_ ) * _CACHE_BLOCK_SIZE_ );
-					( bsClientData->clientBuffer )->readBytes ( offset, owner->fDataCacheStorage, 
+					( bsClientData->clientBuffer )->readBytes ( offset, owner->fDataCacheStorage,
 								( _CACHE_BLOCK_COUNT_ * _CACHE_BLOCK_SIZE_ ) );
-								
+					
 					owner->fDataCacheStartBlock = bsClientData->clientStartingBlock + ( bsClientData->clientRequestedBlockCount - _CACHE_BLOCK_COUNT_ );
 					owner->fDataCacheBlockCount = _CACHE_BLOCK_COUNT_;
 					
@@ -445,17 +455,20 @@ IODVDServices::AsyncReadWriteComplete ( void * 			clientData,
 				IOSimpleLockUnlock ( owner->fDataCacheLock );
 				
 			}
+		
 		}
 #endif
 		
 		IOFree ( clientData, sizeof ( BlockServicesClientData ) );
-
+		
 		// Release the retain for this command.	
 		owner->fProvider->release ( );
 		owner->release ( );
 		
 		IOStorage::complete ( returnData, status, actualByteCount );
+	
 	}
+	
 }
 
 
